@@ -9,6 +9,7 @@ from PIL import Image as PIL_IMAGE
 from assertpy import assert_that
 
 from deepdriver import logger
+from deepdriver.sdk.data_types.boundingBoxes import BoundingBoxes
 from deepdriver.sdk.data_types.media import LOG_TYPE_IMAGE, Media
 from deepdriver.sdk.data_types.run import Run
 from deepdriver.sdk.interface import interface
@@ -16,7 +17,8 @@ from deepdriver.sdk.interface import interface
 
 class Image(Media):
 
-    def __init__(self, data: Union[str, PIL_IMAGE.Image]) -> None:
+    def __init__(self, data: Union[str, PIL_IMAGE.Image], caption: str = None,
+                 boxes: Union[dict[str, BoundingBoxes], dict[str, dict]] = None) -> None:
         super().__init__(log_type=LOG_TYPE_IMAGE)
 
         assert_that(data).is_not_none()
@@ -40,23 +42,42 @@ class Image(Media):
         else:
             raise Exception(f"unknown data type {type(data)}")
 
+        # caption, boxes 처리
+        self.caption = caption
+        self.boxes = None
+
+        if boxes:
+            if isinstance(boxes, BoundingBoxes):
+                self.boxes = boxes
+            elif isinstance(boxes, dict):
+                bb = BoundingBoxes(
+                    key=list(boxes.keys())[0],
+                    box_data=list(boxes.values())[0]['box_data'],
+                    class_labels=list(boxes.values())[0]['class_labels'])
+                self.boxes = bb
+
+
+
     def to_json(self, key_name: str) -> str:
         assert_that(key_name).is_not_none()
 
         return json.dumps({
             "log_type": self.log_type,
-            # "hash": digest,
+            "hash": self.get_digest(),
             "size": self.get_size(),
             "path": self.get_path(key_name),
             "height": self.height,
             "width": self.width,
             "format": self.format,
+            "caption": self.caption if self.caption else "",
+            "boxes": self.boxes.to_json() if self.boxes else "",
+
         })
 
-    def get_size(self):
+    def get_size(self) -> int:
         return os.stat(self.local_path).st_size
 
-    def get_digest(self):
+    def get_digest(self) -> str:
         with open(self.local_path, "rb") as f:
             digest = hashlib.md5(f.read()).hexdigest()
         return digest
